 import { select, csv, 
        scaleLinear, scaleTime, max, 
        extent, axisLeft, 
        axisBottom, format, area,
       	curveBasis} from 'd3';

  const svg = select('svg');

  const height = +svg.attr('height');
  const width = +svg.attr('width');

  let n=0;
  const render = data => {
    	console.log(++n);
    	const title = "World Population";
    	const xValue = d => d.year;
    	const xAxisLabel = "Year";
    
    	const yValue = d => d.population * 1000;
    	const yAxisLabel = "Population";
    
    	const margin = { left:85, top:60, right:40, bottom:88 };
    	const innerWidth = width - margin.left - margin.right;
    	const innerHeight = height - margin.top - margin.bottom;
    	const circleRadius = 6;
    
    	const xScale = scaleTime()
      	.domain(extent(data, xValue))
      	.range([0, innerWidth])
      	.nice()
      ;
    
    	const yScale = scaleLinear()
      	//.domain(extent(data, yValue))
      	.domain([0, max(data, yValue)])
      	.range([innerHeight, 0])
      	.nice()
      	//.padding(0.7)	//no exist for linear scale
      ;
      
  		//const yAxis = axisLeft(yScale);
    	
    
    	const g = svg.append('g')
      	.attr('transform', `translate(${margin.left}, ${margin.top})`);
    
    	//const xAxisTickFormat = number => 
      //	format('.3s')(number).replace('G', 'B');
    
    	const xAxis = axisBottom(xScale)
      	//.tickFormat(xAxisTickFormat)
      	.ticks(6)
      	.tickSize(-innerHeight)
      	.tickPadding(12)
      	;
    
      const yAxisTickFormat = number => 
      	format('.1s')(number).replace('G', 'B');
    
    	const yAxis = axisLeft(yScale)
      	.tickFormat(yAxisTickFormat)
      	.tickSize(-innerWidth)
      	.tickPadding(7)
      ;
      
    
    	//yAxis(g.append('g'));
    	const yAxisGrp = g.append('g').call(yAxis);
    			//.selectAll('.domain, .tick line')
    			
    	yAxisGrp.selectAll('.domain')
    				.remove()
    		;
    
      //problematic, cause graph to disappear
      yAxisGrp.append('text')
        .attr('class', 'axis-label')
        .attr('y', -40)
        .attr('x', -innerHeight/2)
        .attr('fill', 'black')
        .attr('transform', `rotate(-90)`)
        //.attr('transform', 'rotate(-90)')
        .attr('text-anchor', 'middle')
        .text(yAxisLabel)
    		//.attr('transform', 'translate(-90)')
        ;
    
    	const xAixsGrp = g.append('g').call(xAxis)
    		.attr('transform', `translate(0, ${innerHeight})`);
    
    	xAixsGrp.select('.domain').remove();
    
    	xAixsGrp.append('text')
    		.attr('class', 'axis-label')
    		.attr('y', 60)
    		.attr('x', innerWidth/2)
    		.text(xAxisLabel)
    		//.style('fill', 'red')
    	;
    
    	const areaGenerator = area()
      	.x(d => xScale(xValue(d)))
      	.y0(innerHeight)
      	.y1(d => yScale(yValue(d)))
      	.curve(curveBasis)
      ;
    
    	g.append('path')
    		.attr('class', 'line-path')
    		.attr('d', areaGenerator(data))
    	;
    
//     console.log(lineGenerator(data));
    
//   		g.selectAll('circle')
//     		.data(data)
//     		.enter()
//     		.append('circle')
//     			.attr('cy', d => yScale(yValue(d)))
//           .attr('cx', d => xScale(xValue(d)))
//           .attr('r', circleRadius);
//     			//how do I set x, y according to data?
    			
    	g.append('text')
    		.attr('class', 'chart-title')
    		.attr('y', -10)
        .text(title)
    		.attr('transform', `translate(${innerWidth/2}, 0)`)
    		.attr('text-anchor', 'middle')
    	;
  	};

csv('https://vizhub.com/axliao/datasets/World population.csv')
  .then(data => {
  	//console.log(data);
    data.forEach(d => {
      d.year = new Date(d.Year);
      d.population = +d.Population;
      //console.log(d);
    });
    render(data);
  });

